#coding:utf-8

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2019 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
import os

import clcommon
import lvectllib
from cldetectlib import get_param_from_file
from cllimits.clquota_lib import ClQuotaLib


PKG_DIR = "/var/cpanel/packages"
LVE_CONFIG = "/etc/container/ve.cfg"
QUOTA_CONFIG = "/etc/container/cl-quotas.dat"
LIMITS_LIST_NAME = [('ncpu', 'NCPU'), ('cpu', 'SPEED'), ('io', 'IO'), ('mem', 'Vmem'),
                    ('pmem', 'Pmem'), ('nproc', 'NPROC'), ('iops', 'IOPS'), ('ep', 'Max Entry Procs'),
                    ('inodes_soft', 'INODES soft'), ('inodes_hard', 'INODES hard')]

RESELLERS_LIST = '/var/cpanel/resellers'


def get_resellers_list():
    cpanel_resellers = [];
    if os.path.exists(RESELLERS_LIST):
        lines = open(RESELLERS_LIST, 'r')
        for line in lines:
            cpanel_resellers.append(line.split(':')[0])
    return cpanel_resellers


def is_reseller_package(package):
    reseller_list = get_resellers_list()
    for reseller in reseller_list:
        if package.startswith(reseller + '_'):
           return True
    return False


def check_data(data, name, def_value, pkg):
    if (data == None):
        if name == "CPU":
            def_value = str(def_value / 100 ) + "%"  # convert kernel version speed limit to human readable format
        data = def_value
        # log_error(SCRIPT_NAME, "Can\"t get " + name + " settings from " + pkg + ". Use default settings - " + str(def_value))
    return data


def save_package(package):
    """
    Save cpanel package info to LVE config and cl-quotas.dat
    """
    package_path = "%s/%s" % (PKG_DIR, package)
    if not os.path.isfile(package_path):
        return None

    if is_reseller_package(package):
        return None  # we skip all resellers packages

    extention_list = get_param_from_file(package_path,"_PACKAGE_EXTENSIONS","=").split()
    if "lve" not in extention_list:   # skip packages without lve extention
        return None

    lve_data = {'ve_id': package, 'save': True}
    quota_data = dict()
    limit_defaults = lvectllib.ve_defaults.copy()
    limit_defaults.update({'inodes_soft':0, 'inodes_hard':0})
    for couple in LIMITS_LIST_NAME:
        (limit_name, message) = couple
        limit = get_param_from_file(package_path, 'lve_'+str(limit_name), '=')
        if limit == 'DEFAULT':
            continue
        if limit_name == 'cpu':
            limit = clcommon.validate_cpu(limit)
            limit = check_data(limit, message, str(limit_defaults[limit_name] / 100) + "%", package)
        elif limit_name in ('pmem', 'mem', 'vmem'):
            limit = clcommon.memory_to_page(limit, 0)
            limit = check_data(limit, message, limit_defaults[limit_name], package)
        else:
            limit = clcommon.validate_int(limit, 0)
            limit = check_data(limit, message, limit_defaults[limit_name], package)

        if limit_name in ('ncpu', 'cpu', 'io', 'mem', 'pmem', 'nproc', 'iops', 'ep'):
            lve_data[limit_name] = limit
        else:
            quota_data[limit_name] = limit

    lvectllib.package_set(lve_data)
    if len(quota_data) > 0:
        ClQuotaLib().set_package_limits_independently(package, quota_data)
        os.utime(LVE_CONFIG)
    elif len(lve_data) > 0:
        os.utime(QUOTA_CONFIG)
    return True
